==> dinolib-0.9.2.tar.gz: dinolib-0.9.2/lib/tpl2/smarty_plugins/function.dino_listnavi.php <==
<?php {

  // $Id: function.dino_listnavi.php,v 1.3 2003/03/13 14:34:12 noriko Exp $
  // Copyright(c) 2001-2003 Dino Co.,Ltd. All rights reserved.

  /**
   * Smarty plugin: dino_listnavi
   *
   *
   * @package Dino_Tpl2
   * @access public
   */

  function smarty_function_dino_listnavi($params, &$smarty){

    $first_label="&lt;&lt;ǽ";
    $prev_label="&lt;";
    $next_label="&gt;";
    $last_label="&gt;&gt;Ǹ";

    extract($params);

    // $prev $next $start $end
    $url = $list_url;
    //$next = max(0,min($offset + $limit, $count - $limit));
    $next = max(0, $offset+$limit);
    $prev = max(0,$offset-$limit);
    $end = min($count, $offset + $limit);
    $start = $offset+1;
    $to_end = $count - $count % $limit;

    // ѿĤޤ魯
    $get_string="&amp;";
    $ignore_list = array($prefix.'limit',
			 $prefix.'offset',
			 '__sql'
			 );
    foreach($_GET as $key=>$val) {
      $match = false;
      foreach($ignore_list as $ignore){
	if ($key == $ignore) {
	  $match = true;
	}
      }
      if(!$match) {
	$get_string .= $key. "=".$val."&amp;";
      }
    }
    $len = strlen($get_string) - 5;
    $get_string = substr($get_string, 0, $len);
    
    // 
    if($count > 0 && $limit > 0){
      if($start > 1 ){
	printf("<a href=\"%s&amp;%slimit=%d&amp;%soffset=0%s\">%s</a>"
	       , $url , $prefix ,$limit ,$prefix, $get_string, $first_label);
	printf("<a href=\"%s&amp;%slimit=%d&amp;%soffset=%d%s\">%s</a>"
	       ,$url ,$prefix ,$limit,$prefix ,$prev, $get_string, $prev_label);
      }

      printf(" [ %d - %d / %d ] ",$start,$end,$count);
      
      if($count > $end){
	printf("<a href=\"%s&amp;%slimit=%d&amp;%soffset=%d%s\">%s</a>"
	       ,$url ,$prefix ,$limit,$prefix ,$next, $get_string, $next_label);
	printf("<a href=\"%s&amp;%slimit=%d&amp;%soffset=%d%s\">%s</a>"
	       , $url ,$prefix ,$limit,$prefix ,$to_end, $get_string, $last_label);
      }
    }
    // prefix offset limit count url
    if(!empty($type)){

    }
  }
} ?>

==> dinolib-0.9.4a.tar.gz: dinolib-0.9.4a/lib/tpl2/smarty_plugins/function.dino_listnavi.php <==
<?php {

  // $Id: function.dino_listnavi.php,v 1.5 2003/05/30 12:08:24 sato_t Exp $
  // Copyright(c) 2001-2003 Dino Co.,Ltd. All rights reserved.

  /**
   * Smarty plugin: dino_listnavi
   *
   *
   * @package Dino_Tpl2
   * @access public
   */

  function smarty_function_dino_listnavi($params, &$smarty){

    $first_label="&lt;&lt;ǽ";
    $prev_label="&lt;";
    $next_label="&gt;";
    $last_label="&gt;&gt;Ǹ";
    $space_label="&nbsp;";

    extract($params);

    // $prev $next $start $end
    $url = $list_url;
    //$next = max(0,min($offset + $limit, $count - $limit));
    $next = max(0, $offset+$limit);
    $prev = max(0,$offset-$limit);
    $end = min($count, $offset + $limit);
    $start = $offset+1;
    //countlimitǳڤƤޤäϡnavi(Ǹ)ɽoffset
    // - limit ˤ
    $amari = (($count % $limit) == 0 )? $limit : ($count % $limit);
    $to_end = $count - $amari;


    // ѿĤޤ魯
    $get_string="&amp;";
    $ignore_list = array($prefix.'limit',
			 $prefix.'offset',
			 '__sql'
			 );
    foreach($_GET as $key=>$val) {
      $match = false;
      foreach($ignore_list as $ignore){
	if ($key == $ignore) {
	  $match = true;
	}
      }
      if(!$match) {
	$get_string .= $key. "=".$val."&amp;";
      }
    }
    $len = strlen($get_string) - 5;
    $get_string = substr($get_string, 0, $len);
    
    // 
    if($count > 0 && $limit > 0){
      if($start > 1 ){
	printf("<a href=\"%s&amp;%slimit=%d&amp;%soffset=0%s\">%s</a>%s"
	       , $url , $prefix ,$limit ,$prefix, $get_string, $first_label,$space_label);
	printf("<a href=\"%s&amp;%slimit=%d&amp;%soffset=%d%s\">%s</a>%s"
	       ,$url ,$prefix ,$limit,$prefix ,$prev, $get_string, $prev_label,$space_label);
      }

      printf(" [ %d - %d / %d ] ",$start,$end,$count);
      
      if($count > $end){
	printf("%s<a href=\"%s&amp;%slimit=%d&amp;%soffset=%d%s\">%s</a>%s"
	       ,$space_label,$url ,$prefix ,$limit,$prefix ,$next, $get_string, $next_label,$space_label);
	printf("<a href=\"%s&amp;%slimit=%d&amp;%soffset=%d%s\">%s</a>"
	       , $url ,$prefix ,$limit,$prefix ,$to_end, $get_string, $last_label);
      }
    }
    // prefix offset limit count url
    if(!empty($type)){

    }
  }
} ?>
